mailr3628 - /1.3/test_suite/unit_tests/prompt/test_molecule.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 20, 2007 - 10:53:
Author: bugman
Date: Tue Nov 20 10:53:23 2007
New Revision: 3628

URL: http://svn.gna.org/viewcvs/relax?rev=3628&view=rev
Log:
Implemented the pipe_from arg unit test for the molecule.copy() user function.

M    test_suite/unit_tests/prompt/test_molecule.py

Modified:
    1.3/test_suite/unit_tests/prompt/test_molecule.py

Modified: 1.3/test_suite/unit_tests/prompt/test_molecule.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/prompt/test_molecule.py?rev=3628&r1=3627&r2=3628&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/prompt/test_molecule.py (original)
+++ 1.3/test_suite/unit_tests/prompt/test_molecule.py Tue Nov 20 10:53:23 2007
@@ -46,23 +46,23 @@
 
 
 class Test_molecule(Molecule_base_class, TestCase):
     """Unit tests for the functions of the 'generic_fns.spin' module."""
 
     # Instantiate the user function class.
     molecule_fns = Molecule(relax)
 
 
     def test_copy_argfail_pipe_from(self):
-        """Test the proper failure of the spin.copy() user function for the 
pipe_from argument."""
-
-        # Loop over the data types.
-        for data in return_data_types():
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.spin_fns.copy, 
pipe_from=data[1], spin_from='#Old mol:1@111', spin_to='#Old mol:2')
+        """Test the proper failure of the molecule.copy() user function for 
the pipe_from argument."""
+
+        # Loop over the data types.
+        for data in return_data_types():
+            # Catch the None and str arguments, and skip them.
+            if data[0] == 'None' or data[0] == 'str':
+                continue
+
+            # The argument test.
+            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
pipe_from=data[1], mol_from='#Old mol:1@111', mol_to='#Old mol:2')
 
 
@@ -46,23 +46,23 @@
 
 class Test_molecule(Molecule_base_class, TestCase):
-    """Unit tests for the functions of the 'generic_fns.spin' module."""
+    """Unit tests for the functions of the 'generic_fns.molecule' module."""
 
     # Instantiate the user function class.
     def test_copy_argfail_spin_from(self):




Related Messages


Powered by MHonArc, Updated Tue Nov 20 11:00:19 2007